ConcurrentCacheExt

Trait ConcurrentCacheExt 

pub trait ConcurrentCacheExt<K, V> {
    // Required method
    fn sync(&self);
}
Provides extra methods that will be useful for testing.

Required Methods

fn sync(&self)

Performs any pending maintenance operations needed by the cache.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors